/****************************************************************************
** Meta object code from reading C++ file 'sim.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.26.0/src/sim.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sim.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ModemManager3SimE_t {};
} // unnamed namespace

template <> constexpr inline auto ModemManager::Sim::qt_create_metaobjectdata<qt_meta_tag_ZN12ModemManager3SimE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ModemManager::Sim",
        "activeChanged",
        "",
        "active",
        "simIdentifierChanged",
        "identifier",
        "imsiChanged",
        "imsi",
        "eidChanged",
        "eid",
        "operatorIdentifierChanged",
        "operatorNameChanged",
        "name",
        "emergencyNumbersChanged",
        "emergencyNumbers",
        "preferredNetworksChanged",
        "QVariantMap",
        "preferredNetworks",
        "gid1Changed",
        "gid1",
        "gid2Changed",
        "gid2",
        "simTypeChanged",
        "MMSimType",
        "simType",
        "esimStatusChanged",
        "MMSimEsimStatus",
        "esimStatus",
        "removabilityChanged",
        "MMSimRemovability",
        "removability"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'simIdentifierChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'imsiChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'eidChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'operatorIdentifierChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'operatorNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'emergencyNumbersChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Signal 'preferredNetworksChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'gid1Changed'
        QtMocHelpers::SignalData<void(const QByteArray &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 19 },
        }}),
        // Signal 'gid2Changed'
        QtMocHelpers::SignalData<void(const QByteArray &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 21 },
        }}),
        // Signal 'simTypeChanged'
        QtMocHelpers::SignalData<void(MMSimType)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Signal 'esimStatusChanged'
        QtMocHelpers::SignalData<void(MMSimEsimStatus)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Signal 'removabilityChanged'
        QtMocHelpers::SignalData<void(MMSimRemovability)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Sim, qt_meta_tag_ZN12ModemManager3SimE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ModemManager::Sim::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager3SimE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager3SimE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ModemManager3SimE_t>.metaTypes,
    nullptr
} };

void ModemManager::Sim::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Sim *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->simIdentifierChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->imsiChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->eidChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->operatorIdentifierChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->operatorNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->emergencyNumbersChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 7: _t->preferredNetworksChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 8: _t->gid1Changed((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 9: _t->gid2Changed((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 10: _t->simTypeChanged((*reinterpret_cast<std::add_pointer_t<MMSimType>>(_a[1]))); break;
        case 11: _t->esimStatusChanged((*reinterpret_cast<std::add_pointer_t<MMSimEsimStatus>>(_a[1]))); break;
        case 12: _t->removabilityChanged((*reinterpret_cast<std::add_pointer_t<MMSimRemovability>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMSimType >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMSimEsimStatus >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMSimRemovability >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(bool )>(_a, &Sim::activeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(const QString & )>(_a, &Sim::simIdentifierChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(const QString & )>(_a, &Sim::imsiChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(const QString & )>(_a, &Sim::eidChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(const QString & )>(_a, &Sim::operatorIdentifierChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(const QString & )>(_a, &Sim::operatorNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(const QStringList & )>(_a, &Sim::emergencyNumbersChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(const QVariantMap & )>(_a, &Sim::preferredNetworksChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(const QByteArray & )>(_a, &Sim::gid1Changed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(const QByteArray & )>(_a, &Sim::gid2Changed, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(MMSimType )>(_a, &Sim::simTypeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(MMSimEsimStatus )>(_a, &Sim::esimStatusChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sim::*)(MMSimRemovability )>(_a, &Sim::removabilityChanged, 12))
            return;
    }
}

const QMetaObject *ModemManager::Sim::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ModemManager::Sim::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager3SimE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ModemManager::Sim::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ModemManager::Sim::activeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ModemManager::Sim::simIdentifierChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ModemManager::Sim::imsiChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ModemManager::Sim::eidChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ModemManager::Sim::operatorIdentifierChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ModemManager::Sim::operatorNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ModemManager::Sim::emergencyNumbersChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ModemManager::Sim::preferredNetworksChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ModemManager::Sim::gid1Changed(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ModemManager::Sim::gid2Changed(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ModemManager::Sim::simTypeChanged(MMSimType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void ModemManager::Sim::esimStatusChanged(MMSimEsimStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ModemManager::Sim::removabilityChanged(MMSimRemovability _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}
QT_WARNING_POP
