/****************************************************************************
** Meta object code from reading C++ file 'smsinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.26.0/src/dbus/smsinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'smsinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN39OrgFreedesktopModemManager1SmsInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopModemManager1SmsInterface::qt_create_metaobjectdata<qt_meta_tag_ZN39OrgFreedesktopModemManager1SmsInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopModemManager1SmsInterface",
        "Send",
        "QDBusPendingReply<>",
        "",
        "Store",
        "storage",
        "SmsClass",
        "Data",
        "DeliveryReportRequest",
        "DeliveryState",
        "DischargeTimestamp",
        "MessageReference",
        "Number",
        "PduType",
        "SMSC",
        "ServiceCategory",
        "State",
        "Storage",
        "TeleserviceId",
        "Text",
        "Timestamp",
        "Validity",
        "ModemManager::ValidityPair"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Send'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'Store'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(4, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'SmsClass'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'Data'
        QtMocHelpers::PropertyData<QByteArray>(7, QMetaType::QByteArray, QMC::DefaultPropertyFlags),
        // property 'DeliveryReportRequest'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'DeliveryState'
        QtMocHelpers::PropertyData<uint>(9, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'DischargeTimestamp'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'MessageReference'
        QtMocHelpers::PropertyData<uint>(11, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Number'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'PduType'
        QtMocHelpers::PropertyData<uint>(13, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'SMSC'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'ServiceCategory'
        QtMocHelpers::PropertyData<uint>(15, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'State'
        QtMocHelpers::PropertyData<uint>(16, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Storage'
        QtMocHelpers::PropertyData<uint>(17, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'TeleserviceId'
        QtMocHelpers::PropertyData<uint>(18, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Text'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Timestamp'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Validity'
        QtMocHelpers::PropertyData<ModemManager::ValidityPair>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopModemManager1SmsInterface, qt_meta_tag_ZN39OrgFreedesktopModemManager1SmsInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopModemManager1SmsInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopModemManager1SmsInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopModemManager1SmsInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN39OrgFreedesktopModemManager1SmsInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopModemManager1SmsInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopModemManager1SmsInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->Send();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->Store((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 15:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ModemManager::ValidityPair >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->smsClass(); break;
        case 1: *reinterpret_cast<QByteArray*>(_v) = _t->data(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->deliveryReportRequest(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->deliveryState(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->dischargeTimestamp(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->messageReference(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->number(); break;
        case 7: *reinterpret_cast<uint*>(_v) = _t->pduType(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->SMSC(); break;
        case 9: *reinterpret_cast<uint*>(_v) = _t->serviceCategory(); break;
        case 10: *reinterpret_cast<uint*>(_v) = _t->state(); break;
        case 11: *reinterpret_cast<uint*>(_v) = _t->storage(); break;
        case 12: *reinterpret_cast<uint*>(_v) = _t->teleserviceId(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->timestamp(); break;
        case 15: *reinterpret_cast<ModemManager::ValidityPair*>(_v) = _t->validity(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopModemManager1SmsInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopModemManager1SmsInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopModemManager1SmsInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopModemManager1SmsInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}
QT_WARNING_POP
