/****************************************************************************
** Meta object code from reading C++ file 'omainterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.26.0/src/dbus/omainterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'omainterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN44OrgFreedesktopModemManager1ModemOmaInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopModemManager1ModemOmaInterface::qt_create_metaobjectdata<qt_meta_tag_ZN44OrgFreedesktopModemManager1ModemOmaInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopModemManager1ModemOmaInterface",
        "SessionStateChanged",
        "",
        "old_session_state",
        "new_session_state",
        "session_state_failed_reason",
        "AcceptNetworkInitiatedSession",
        "QDBusPendingReply<>",
        "session_id",
        "accept",
        "CancelSession",
        "Setup",
        "features",
        "StartClientInitiatedSession",
        "session_type",
        "Features",
        "PendingNetworkInitiatedSessions",
        "ModemManager::OmaSessionTypes",
        "SessionState",
        "SessionType"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'SessionStateChanged'
        QtMocHelpers::SignalData<void(int, int, uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 }, { QMetaType::UInt, 5 },
        }}),
        // Slot 'AcceptNetworkInitiatedSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, bool)>(6, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::UInt, 8 }, { QMetaType::Bool, 9 },
        }}),
        // Slot 'CancelSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(10, 2, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'Setup'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(11, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::UInt, 12 },
        }}),
        // Slot 'StartClientInitiatedSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(13, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::UInt, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Features'
        QtMocHelpers::PropertyData<uint>(15, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'PendingNetworkInitiatedSessions'
        QtMocHelpers::PropertyData<ModemManager::OmaSessionTypes>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'SessionState'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'SessionType'
        QtMocHelpers::PropertyData<uint>(19, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopModemManager1ModemOmaInterface, qt_meta_tag_ZN44OrgFreedesktopModemManager1ModemOmaInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopModemManager1ModemOmaInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44OrgFreedesktopModemManager1ModemOmaInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44OrgFreedesktopModemManager1ModemOmaInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN44OrgFreedesktopModemManager1ModemOmaInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopModemManager1ModemOmaInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopModemManager1ModemOmaInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->SessionStateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 1: { QDBusPendingReply<> _r = _t->AcceptNetworkInitiatedSession((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->CancelSession();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->Setup((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->StartClientInitiatedSession((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopModemManager1ModemOmaInterface::*)(int , int , uint )>(_a, &OrgFreedesktopModemManager1ModemOmaInterface::SessionStateChanged, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ModemManager::OmaSessionTypes >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->features(); break;
        case 1: *reinterpret_cast<ModemManager::OmaSessionTypes*>(_v) = _t->pendingNetworkInitiatedSessions(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->sessionState(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->sessionType(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopModemManager1ModemOmaInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopModemManager1ModemOmaInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN44OrgFreedesktopModemManager1ModemOmaInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopModemManager1ModemOmaInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopModemManager1ModemOmaInterface::SessionStateChanged(int _t1, int _t2, uint _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
