/****************************************************************************
** Meta object code from reading C++ file 'modemoma.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.26.0/src/modemoma.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'modemoma.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ModemManager8ModemOmaE_t {};
} // unnamed namespace

template <> constexpr inline auto ModemManager::ModemOma::qt_create_metaobjectdata<qt_meta_tag_ZN12ModemManager8ModemOmaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ModemManager::ModemOma",
        "featuresChanged",
        "",
        "QFlags<MMOmaFeature>",
        "features",
        "pendingNetworkInitiatedSessionsChanged",
        "ModemManager::OmaSessionTypes",
        "sessions",
        "sessionTypeChanged",
        "MMOmaSessionType",
        "sessionType",
        "sessionStateChanged",
        "MMOmaSessionState",
        "oldState",
        "newState",
        "MMOmaSessionStateFailedReason",
        "failedReason"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'featuresChanged'
        QtMocHelpers::SignalData<void(QFlags<MMOmaFeature>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'pendingNetworkInitiatedSessionsChanged'
        QtMocHelpers::SignalData<void(const ModemManager::OmaSessionTypes &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sessionTypeChanged'
        QtMocHelpers::SignalData<void(MMOmaSessionType)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'sessionStateChanged'
        QtMocHelpers::SignalData<void(MMOmaSessionState, MMOmaSessionState, MMOmaSessionStateFailedReason)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 12, 14 }, { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ModemOma, qt_meta_tag_ZN12ModemManager8ModemOmaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ModemManager::ModemOma::staticMetaObject = { {
    QMetaObject::SuperData::link<Interface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager8ModemOmaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager8ModemOmaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ModemManager8ModemOmaE_t>.metaTypes,
    nullptr
} };

void ModemManager::ModemOma::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ModemOma *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->featuresChanged((*reinterpret_cast<std::add_pointer_t<QFlags<MMOmaFeature>>>(_a[1]))); break;
        case 1: _t->pendingNetworkInitiatedSessionsChanged((*reinterpret_cast<std::add_pointer_t<ModemManager::OmaSessionTypes>>(_a[1]))); break;
        case 2: _t->sessionTypeChanged((*reinterpret_cast<std::add_pointer_t<MMOmaSessionType>>(_a[1]))); break;
        case 3: _t->sessionStateChanged((*reinterpret_cast<std::add_pointer_t<MMOmaSessionState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<MMOmaSessionState>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<MMOmaSessionStateFailedReason>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFlags<MMOmaFeature> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ModemManager::OmaSessionTypes >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMOmaSessionType >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMOmaSessionState >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMOmaSessionStateFailedReason >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ModemOma::*)(QFlags<MMOmaFeature> )>(_a, &ModemOma::featuresChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemOma::*)(const ModemManager::OmaSessionTypes & )>(_a, &ModemOma::pendingNetworkInitiatedSessionsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemOma::*)(MMOmaSessionType )>(_a, &ModemOma::sessionTypeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemOma::*)(MMOmaSessionState , MMOmaSessionState , MMOmaSessionStateFailedReason )>(_a, &ModemOma::sessionStateChanged, 3))
            return;
    }
}

const QMetaObject *ModemManager::ModemOma::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ModemManager::ModemOma::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager8ModemOmaE_t>.strings))
        return static_cast<void*>(this);
    return Interface::qt_metacast(_clname);
}

int ModemManager::ModemOma::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Interface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void ModemManager::ModemOma::featuresChanged(QFlags<MMOmaFeature> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ModemManager::ModemOma::pendingNetworkInitiatedSessionsChanged(const ModemManager::OmaSessionTypes & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ModemManager::ModemOma::sessionTypeChanged(MMOmaSessionType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ModemManager::ModemOma::sessionStateChanged(MMOmaSessionState _t1, MMOmaSessionState _t2, MMOmaSessionStateFailedReason _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
