/****************************************************************************
** Meta object code from reading C++ file 'siminterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.26.0/src/dbus/siminterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'siminterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN39OrgFreedesktopModemManager1SimInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopModemManager1SimInterface::qt_create_metaobjectdata<qt_meta_tag_ZN39OrgFreedesktopModemManager1SimInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopModemManager1SimInterface",
        "ChangePin",
        "QDBusPendingReply<>",
        "",
        "old_pin",
        "new_pin",
        "EnablePin",
        "pin",
        "enabled",
        "SendPin",
        "SendPuk",
        "puk",
        "SetPreferredNetworks",
        "QVariantMap",
        "preferred_networks",
        "Active",
        "Eid",
        "EmergencyNumbers",
        "EsimStatus",
        "Gid1",
        "Gid2",
        "Imsi",
        "OperatorIdentifier",
        "OperatorName",
        "PreferredNetworks",
        "Removability",
        "SimIdentifier",
        "SimType"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'ChangePin'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'EnablePin'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(6, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 8 },
        }}),
        // Slot 'SendPin'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(9, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'SendPuk'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(10, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'SetPreferredNetworks'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(12, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 13, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Active'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Eid'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'EmergencyNumbers'
        QtMocHelpers::PropertyData<QStringList>(17, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'EsimStatus'
        QtMocHelpers::PropertyData<uint>(18, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Gid1'
        QtMocHelpers::PropertyData<QByteArray>(19, QMetaType::QByteArray, QMC::DefaultPropertyFlags),
        // property 'Gid2'
        QtMocHelpers::PropertyData<QByteArray>(20, QMetaType::QByteArray, QMC::DefaultPropertyFlags),
        // property 'Imsi'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'OperatorIdentifier'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'OperatorName'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'PreferredNetworks'
        QtMocHelpers::PropertyData<QVariantMap>(24, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Removability'
        QtMocHelpers::PropertyData<uint>(25, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'SimIdentifier'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'SimType'
        QtMocHelpers::PropertyData<uint>(27, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopModemManager1SimInterface, qt_meta_tag_ZN39OrgFreedesktopModemManager1SimInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopModemManager1SimInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopModemManager1SimInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopModemManager1SimInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN39OrgFreedesktopModemManager1SimInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopModemManager1SimInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopModemManager1SimInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->ChangePin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->EnablePin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->SendPin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->SendPuk((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->SetPreferredNetworks((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->eid(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->emergencyNumbers(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->esimStatus(); break;
        case 4: *reinterpret_cast<QByteArray*>(_v) = _t->gid1(); break;
        case 5: *reinterpret_cast<QByteArray*>(_v) = _t->gid2(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->imsi(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->operatorIdentifier(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->operatorName(); break;
        case 9: *reinterpret_cast<QVariantMap*>(_v) = _t->preferredNetworks(); break;
        case 10: *reinterpret_cast<uint*>(_v) = _t->removability(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->simIdentifier(); break;
        case 12: *reinterpret_cast<uint*>(_v) = _t->simType(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopModemManager1SimInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopModemManager1SimInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39OrgFreedesktopModemManager1SimInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopModemManager1SimInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
