/****************************************************************************
** Meta object code from reading C++ file 'signalinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.26.0/src/dbus/signalinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'signalinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN47OrgFreedesktopModemManager1ModemSignalInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopModemManager1ModemSignalInterface::qt_create_metaobjectdata<qt_meta_tag_ZN47OrgFreedesktopModemManager1ModemSignalInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopModemManager1ModemSignalInterface",
        "Setup",
        "QDBusPendingReply<>",
        "",
        "rate",
        "SetupThresholds",
        "QVariantMap",
        "settings",
        "Cdma",
        "Evdo",
        "Gsm",
        "Lte",
        "Nr5g",
        "Rate",
        "RssiThreshold",
        "ErrorRateThreshold",
        "Umts"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Setup'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::UInt, 4 },
        }}),
        // Slot 'SetupThresholds'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(5, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Cdma'
        QtMocHelpers::PropertyData<QVariantMap>(8, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Evdo'
        QtMocHelpers::PropertyData<QVariantMap>(9, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Gsm'
        QtMocHelpers::PropertyData<QVariantMap>(10, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Lte'
        QtMocHelpers::PropertyData<QVariantMap>(11, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Nr5g'
        QtMocHelpers::PropertyData<QVariantMap>(12, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Rate'
        QtMocHelpers::PropertyData<uint>(13, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'RssiThreshold'
        QtMocHelpers::PropertyData<uint>(14, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'ErrorRateThreshold'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Umts'
        QtMocHelpers::PropertyData<QVariantMap>(16, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopModemManager1ModemSignalInterface, qt_meta_tag_ZN47OrgFreedesktopModemManager1ModemSignalInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopModemManager1ModemSignalInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN47OrgFreedesktopModemManager1ModemSignalInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN47OrgFreedesktopModemManager1ModemSignalInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN47OrgFreedesktopModemManager1ModemSignalInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopModemManager1ModemSignalInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopModemManager1ModemSignalInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<> _r = _t->Setup((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->SetupThresholds((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantMap*>(_v) = _t->cdma(); break;
        case 1: *reinterpret_cast<QVariantMap*>(_v) = _t->evdo(); break;
        case 2: *reinterpret_cast<QVariantMap*>(_v) = _t->gsm(); break;
        case 3: *reinterpret_cast<QVariantMap*>(_v) = _t->lte(); break;
        case 4: *reinterpret_cast<QVariantMap*>(_v) = _t->nr5g(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->rate(); break;
        case 6: *reinterpret_cast<uint*>(_v) = _t->rssiThreshold(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->errorRateThreshold(); break;
        case 8: *reinterpret_cast<QVariantMap*>(_v) = _t->umts(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopModemManager1ModemSignalInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopModemManager1ModemSignalInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN47OrgFreedesktopModemManager1ModemSignalInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopModemManager1ModemSignalInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
