/****************************************************************************
** Meta object code from reading C++ file 'modemlocation.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.26.0/src/modemlocation.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'modemlocation.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ModemManager13ModemLocationE_t {};
} // unnamed namespace

template <> constexpr inline auto ModemManager::ModemLocation::qt_create_metaobjectdata<qt_meta_tag_ZN12ModemManager13ModemLocationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ModemManager::ModemLocation",
        "capabilitiesChanged",
        "",
        "QFlags<MMModemLocationSource>",
        "capabilities",
        "enabledCapabilitiesChanged",
        "supportedAssistanceDataChanged",
        "QFlags<MMModemLocationAssistanceDataType>",
        "supported",
        "suplServerChanged",
        "server",
        "assistanceDataServersChanged",
        "servers",
        "gpsRefreshRateChanged",
        "rate",
        "signalsLocationChanged",
        "signalsLocation",
        "locationChanged",
        "ModemManager::LocationInformationMap",
        "location"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'capabilitiesChanged'
        QtMocHelpers::SignalData<void(QFlags<MMModemLocationSource>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'enabledCapabilitiesChanged'
        QtMocHelpers::SignalData<void(QFlags<MMModemLocationSource>)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'supportedAssistanceDataChanged'
        QtMocHelpers::SignalData<void(QFlags<MMModemLocationAssistanceDataType>)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'suplServerChanged'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'assistanceDataServersChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 12 },
        }}),
        // Signal 'gpsRefreshRateChanged'
        QtMocHelpers::SignalData<void(uint)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 14 },
        }}),
        // Signal 'signalsLocationChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'locationChanged'
        QtMocHelpers::SignalData<void(const ModemManager::LocationInformationMap &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ModemLocation, qt_meta_tag_ZN12ModemManager13ModemLocationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ModemManager::ModemLocation::staticMetaObject = { {
    QMetaObject::SuperData::link<Interface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager13ModemLocationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager13ModemLocationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ModemManager13ModemLocationE_t>.metaTypes,
    nullptr
} };

void ModemManager::ModemLocation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ModemLocation *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->capabilitiesChanged((*reinterpret_cast<std::add_pointer_t<QFlags<MMModemLocationSource>>>(_a[1]))); break;
        case 1: _t->enabledCapabilitiesChanged((*reinterpret_cast<std::add_pointer_t<QFlags<MMModemLocationSource>>>(_a[1]))); break;
        case 2: _t->supportedAssistanceDataChanged((*reinterpret_cast<std::add_pointer_t<QFlags<MMModemLocationAssistanceDataType>>>(_a[1]))); break;
        case 3: _t->suplServerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->assistanceDataServersChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->gpsRefreshRateChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 6: _t->signalsLocationChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->locationChanged((*reinterpret_cast<std::add_pointer_t<ModemManager::LocationInformationMap>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFlags<MMModemLocationSource> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFlags<MMModemLocationSource> >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ModemManager::LocationInformationMap >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ModemLocation::*)(QFlags<MMModemLocationSource> )>(_a, &ModemLocation::capabilitiesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemLocation::*)(QFlags<MMModemLocationSource> )>(_a, &ModemLocation::enabledCapabilitiesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemLocation::*)(QFlags<MMModemLocationAssistanceDataType> )>(_a, &ModemLocation::supportedAssistanceDataChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemLocation::*)(const QString & )>(_a, &ModemLocation::suplServerChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemLocation::*)(const QStringList & )>(_a, &ModemLocation::assistanceDataServersChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemLocation::*)(uint )>(_a, &ModemLocation::gpsRefreshRateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemLocation::*)(bool )>(_a, &ModemLocation::signalsLocationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModemLocation::*)(const ModemManager::LocationInformationMap & )>(_a, &ModemLocation::locationChanged, 7))
            return;
    }
}

const QMetaObject *ModemManager::ModemLocation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ModemManager::ModemLocation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager13ModemLocationE_t>.strings))
        return static_cast<void*>(this);
    return Interface::qt_metacast(_clname);
}

int ModemManager::ModemLocation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Interface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void ModemManager::ModemLocation::capabilitiesChanged(QFlags<MMModemLocationSource> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ModemManager::ModemLocation::enabledCapabilitiesChanged(QFlags<MMModemLocationSource> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ModemManager::ModemLocation::supportedAssistanceDataChanged(QFlags<MMModemLocationAssistanceDataType> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ModemManager::ModemLocation::suplServerChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ModemManager::ModemLocation::assistanceDataServersChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ModemManager::ModemLocation::gpsRefreshRateChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ModemManager::ModemLocation::signalsLocationChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ModemManager::ModemLocation::locationChanged(const ModemManager::LocationInformationMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
