/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -N -m -i ../generictypes.h -p siminterface
 * /home/devin/kde/src/modemmanager-qt/src/dbus/introspection/org.freedesktop.ModemManager1.Modem.CellBroadcast.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef MODEMMANAGERQT_CELLBROADCASTINTERFACE_H
#define MODEMMANAGERQT_CELLBROADCASTINTERFACE_H

#include "generictypes.h"
#include "generictypes_p.h"
#include <QDBusAbstractInterface>
#include <QDBusObjectPath>
#include <QDBusPendingReply>
#include <QList>
#include <QObject>
#include <QString>
#include <QVariant>

/*
 * Proxy class for interface org.freedesktop.ModemManager1.Modem.CellBroadcast
 */
class OrgFreedesktopModemManager1ModemCellBroadcastInterface : public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
#ifdef MMQT_STATIC
    {
        return "org.kde.fakemodem.Modem.CellBroadcast";
    }
#else
    {
        return "org.freedesktop.ModemManager1.Modem.CellBroadcast";
    }
#endif
public:
    OrgFreedesktopModemManager1ModemCellBroadcastInterface(const QString &service,
                                                           const QString &path,
                                                           const QDBusConnection &connection,
                                                           QObject *parent = nullptr);

    ~OrgFreedesktopModemManager1ModemCellBroadcastInterface() override;

    Q_PROPERTY(QList<QDBusObjectPath> CellBroadcasts READ cellBroadcasts)
    inline QList<QDBusObjectPath> cellBroadcasts() const
    {
        return qvariant_cast<QList<QDBusObjectPath>>(property("CellBroadcasts"));
    }

    Q_PROPERTY(ModemManager::CellBroadcastChannelRangeList Channels READ channels)
    inline ModemManager::CellBroadcastChannelRangeList channels() const
    {
        return qvariant_cast<ModemManager::CellBroadcastChannelRangeList>(property("Channels"));
    }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QList<QDBusObjectPath>> List()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QLatin1String("List"), argumentList);
    }

    inline QDBusPendingReply<> Delete(const QDBusObjectPath &path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(path);
        return asyncCallWithArgumentList(QLatin1String("Delete"), argumentList);
    }

    inline QDBusPendingReply<> SetChannels(const ModemManager::CellBroadcastChannelRangeList &channels)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(channels);
        return asyncCallWithArgumentList(QLatin1String("SetChannels"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void Added(const QDBusObjectPath &path);
    void Deleted(const QDBusObjectPath &path);
};

#endif
