/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -N -m -i ../generictypes.h -p siminterface
 * /home/devin/kde/src/modemmanager-qt/src/dbus/introspection/org.freedesktop.ModemManager1.Cbm.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef MODEMMANAGERQT_CBMINTERFACE_H
#define MODEMMANAGERQT_CBMINTERFACE_H

#include "generictypes.h"
#include <QDBusAbstractInterface>
#include <QDBusPendingReply>
#include <QObject>
#include <QString>
#include <QVariant>

/*
 * Proxy class for interface org.freedesktop.ModemManager1.Cbm
 */
class OrgFreedesktopModemManager1CbmInterface : public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
#ifdef MMQT_STATIC
    {
        return "org.kde.fakemodem.Cbm";
    }
#else
    {
        return "org.freedesktop.ModemManager1.Cbm";
    }
#endif
public:
    OrgFreedesktopModemManager1CbmInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopModemManager1CbmInterface() override;

    Q_PROPERTY(uint State READ state)
    inline uint state() const
    {
        return qvariant_cast<uint>(property("State"));
    }

    Q_PROPERTY(QString Text READ text)
    inline QString text() const
    {
        return qvariant_cast<QString>(property("Text"));
    }

    Q_PROPERTY(uint Channel READ channel)
    inline uint channel() const
    {
        return qvariant_cast<uint>(property("Channel"));
    }

    Q_PROPERTY(uint MessageCode READ messageCode)
    inline uint messageCode() const
    {
        return qvariant_cast<uint>(property("MessageCode"));
    }

    Q_PROPERTY(uint Update READ update)
    inline uint update() const
    {
        return qvariant_cast<uint>(property("Update"));
    }

public Q_SLOTS: // METHODS

Q_SIGNALS: // SIGNALS
};

#endif
