/****************************************************************************
** Meta object code from reading C++ file 'sms.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.26.0/src/sms.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sms.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ModemManager3SmsE_t {};
} // unnamed namespace

template <> constexpr inline auto ModemManager::Sms::qt_create_metaobjectdata<qt_meta_tag_ZN12ModemManager3SmsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ModemManager::Sms",
        "stateChanged",
        "",
        "MMSmsState",
        "newState",
        "pduTypeChanged",
        "MMSmsPduType",
        "pduType",
        "numberChanged",
        "number",
        "SMSCChanged",
        "smsc",
        "dataChanged",
        "data",
        "textChanged",
        "text",
        "validityChanged",
        "ModemManager::ValidityPair",
        "validity",
        "smsClassChanged",
        "smsClass",
        "deliveryReportRequestChanged",
        "deliveryReportRequest",
        "messageReferenceChanged",
        "messageReference",
        "timestampChanged",
        "timestamp",
        "dischargeTimestampChanged",
        "dischargeTimestamp",
        "deliveryStateChanged",
        "MMSmsDeliveryState",
        "newDeliveryState",
        "storageChanged",
        "MMSmsStorage",
        "storage",
        "serviceCategoryChanged",
        "MMSmsCdmaServiceCategory",
        "serviceCategory",
        "teleserviceIdChanged",
        "MMSmsCdmaTeleserviceId",
        "teleserviceId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(MMSmsState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'pduTypeChanged'
        QtMocHelpers::SignalData<void(MMSmsPduType)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'numberChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'SMSCChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 13 },
        }}),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'validityChanged'
        QtMocHelpers::SignalData<void(const ModemManager::ValidityPair &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'smsClassChanged'
        QtMocHelpers::SignalData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Signal 'deliveryReportRequestChanged'
        QtMocHelpers::SignalData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'messageReferenceChanged'
        QtMocHelpers::SignalData<void(uint)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 24 },
        }}),
        // Signal 'timestampChanged'
        QtMocHelpers::SignalData<void(const QDateTime &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 26 },
        }}),
        // Signal 'dischargeTimestampChanged'
        QtMocHelpers::SignalData<void(const QDateTime &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 28 },
        }}),
        // Signal 'deliveryStateChanged'
        QtMocHelpers::SignalData<void(MMSmsDeliveryState)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Signal 'storageChanged'
        QtMocHelpers::SignalData<void(MMSmsStorage)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Signal 'serviceCategoryChanged'
        QtMocHelpers::SignalData<void(MMSmsCdmaServiceCategory)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Signal 'teleserviceIdChanged'
        QtMocHelpers::SignalData<void(MMSmsCdmaTeleserviceId)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Sms, qt_meta_tag_ZN12ModemManager3SmsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ModemManager::Sms::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager3SmsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager3SmsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ModemManager3SmsE_t>.metaTypes,
    nullptr
} };

void ModemManager::Sms::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Sms *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<MMSmsState>>(_a[1]))); break;
        case 1: _t->pduTypeChanged((*reinterpret_cast<std::add_pointer_t<MMSmsPduType>>(_a[1]))); break;
        case 2: _t->numberChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->SMSCChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->dataChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 5: _t->textChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->validityChanged((*reinterpret_cast<std::add_pointer_t<ModemManager::ValidityPair>>(_a[1]))); break;
        case 7: _t->smsClassChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->deliveryReportRequestChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->messageReferenceChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 10: _t->timestampChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 11: _t->dischargeTimestampChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 12: _t->deliveryStateChanged((*reinterpret_cast<std::add_pointer_t<MMSmsDeliveryState>>(_a[1]))); break;
        case 13: _t->storageChanged((*reinterpret_cast<std::add_pointer_t<MMSmsStorage>>(_a[1]))); break;
        case 14: _t->serviceCategoryChanged((*reinterpret_cast<std::add_pointer_t<MMSmsCdmaServiceCategory>>(_a[1]))); break;
        case 15: _t->teleserviceIdChanged((*reinterpret_cast<std::add_pointer_t<MMSmsCdmaTeleserviceId>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMSmsState >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMSmsPduType >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ModemManager::ValidityPair >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMSmsDeliveryState >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMSmsStorage >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMSmsCdmaServiceCategory >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MMSmsCdmaTeleserviceId >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(MMSmsState )>(_a, &Sms::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(MMSmsPduType )>(_a, &Sms::pduTypeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(const QString & )>(_a, &Sms::numberChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(const QString & )>(_a, &Sms::SMSCChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(const QByteArray & )>(_a, &Sms::dataChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(const QString & )>(_a, &Sms::textChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(const ModemManager::ValidityPair & )>(_a, &Sms::validityChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(int )>(_a, &Sms::smsClassChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(bool )>(_a, &Sms::deliveryReportRequestChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(uint )>(_a, &Sms::messageReferenceChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(const QDateTime & )>(_a, &Sms::timestampChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(const QDateTime & )>(_a, &Sms::dischargeTimestampChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(MMSmsDeliveryState )>(_a, &Sms::deliveryStateChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(MMSmsStorage )>(_a, &Sms::storageChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(MMSmsCdmaServiceCategory )>(_a, &Sms::serviceCategoryChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sms::*)(MMSmsCdmaTeleserviceId )>(_a, &Sms::teleserviceIdChanged, 15))
            return;
    }
}

const QMetaObject *ModemManager::Sms::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ModemManager::Sms::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ModemManager3SmsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ModemManager::Sms::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void ModemManager::Sms::stateChanged(MMSmsState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ModemManager::Sms::pduTypeChanged(MMSmsPduType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ModemManager::Sms::numberChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ModemManager::Sms::SMSCChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ModemManager::Sms::dataChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ModemManager::Sms::textChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ModemManager::Sms::validityChanged(const ModemManager::ValidityPair & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ModemManager::Sms::smsClassChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ModemManager::Sms::deliveryReportRequestChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ModemManager::Sms::messageReferenceChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ModemManager::Sms::timestampChanged(const QDateTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void ModemManager::Sms::dischargeTimestampChanged(const QDateTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ModemManager::Sms::deliveryStateChanged(MMSmsDeliveryState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void ModemManager::Sms::storageChanged(MMSmsStorage _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void ModemManager::Sms::serviceCategoryChanged(MMSmsCdmaServiceCategory _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void ModemManager::Sms::teleserviceIdChanged(MMSmsCdmaTeleserviceId _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}
QT_WARNING_POP
