/****************************************************************************
** Meta object code from reading C++ file 'dbus_manager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.26.0/src/dbus/dbus_manager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbus_manager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN40OrgFreedesktopDBusObjectManagerInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopDBusObjectManagerInterface::qt_create_metaobjectdata<qt_meta_tag_ZN40OrgFreedesktopDBusObjectManagerInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopDBusObjectManagerInterface",
        "InterfacesAdded",
        "",
        "QDBusObjectPath",
        "object_path",
        "ModemManager::MMVariantMapMap",
        "interfaces_and_properties",
        "InterfacesRemoved",
        "interfaces",
        "GetManagedObjects",
        "QDBusPendingReply<ModemManager::DBUSManagerStruct>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'InterfacesAdded'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const ModemManager::MMVariantMapMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'InterfacesRemoved'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, const QStringList &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QStringList, 8 },
        }}),
        // Slot 'GetManagedObjects'
        QtMocHelpers::SlotData<QDBusPendingReply<ModemManager::DBUSManagerStruct>()>(9, 2, QMC::AccessPublic, 0x80000000 | 10),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopDBusObjectManagerInterface, qt_meta_tag_ZN40OrgFreedesktopDBusObjectManagerInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopDBusObjectManagerInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40OrgFreedesktopDBusObjectManagerInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40OrgFreedesktopDBusObjectManagerInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN40OrgFreedesktopDBusObjectManagerInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopDBusObjectManagerInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopDBusObjectManagerInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->InterfacesAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ModemManager::MMVariantMapMap>>(_a[2]))); break;
        case 1: _t->InterfacesRemoved((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 2: { QDBusPendingReply<ModemManager::DBUSManagerStruct> _r = _t->GetManagedObjects();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<ModemManager::DBUSManagerStruct>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ModemManager::MMVariantMapMap >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopDBusObjectManagerInterface::*)(const QDBusObjectPath & , const ModemManager::MMVariantMapMap & )>(_a, &OrgFreedesktopDBusObjectManagerInterface::InterfacesAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopDBusObjectManagerInterface::*)(const QDBusObjectPath & , const QStringList & )>(_a, &OrgFreedesktopDBusObjectManagerInterface::InterfacesRemoved, 1))
            return;
    }
}

const QMetaObject *OrgFreedesktopDBusObjectManagerInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopDBusObjectManagerInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40OrgFreedesktopDBusObjectManagerInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopDBusObjectManagerInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopDBusObjectManagerInterface::InterfacesAdded(const QDBusObjectPath & _t1, const ModemManager::MMVariantMapMap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void OrgFreedesktopDBusObjectManagerInterface::InterfacesRemoved(const QDBusObjectPath & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
