/****************************************************************************
** Meta object code from reading C++ file 'modemcdmainterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.26.0/src/dbus/modemcdmainterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'modemcdmainterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemModemCdmaInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopModemManager1ModemModemCdmaInterface::qt_create_metaobjectdata<qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemModemCdmaInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopModemManager1ModemModemCdmaInterface",
        "ActivationStateChanged",
        "",
        "activation_state",
        "activation_error",
        "QVariantMap",
        "status_changes",
        "Activate",
        "QDBusPendingReply<>",
        "carrier_code",
        "ActivateManual",
        "properties",
        "ActivationState",
        "Cdma1xRegistrationState",
        "Esn",
        "EvdoRegistrationState",
        "Meid",
        "Nid",
        "Sid"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActivationStateChanged'
        QtMocHelpers::SignalData<void(uint, uint, const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'Activate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'ActivateManual'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(10, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 5, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ActivationState'
        QtMocHelpers::PropertyData<uint>(12, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Cdma1xRegistrationState'
        QtMocHelpers::PropertyData<uint>(13, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Esn'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'EvdoRegistrationState'
        QtMocHelpers::PropertyData<uint>(15, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Meid'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Nid'
        QtMocHelpers::PropertyData<uint>(17, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Sid'
        QtMocHelpers::PropertyData<uint>(18, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopModemManager1ModemModemCdmaInterface, qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemModemCdmaInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopModemManager1ModemModemCdmaInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemModemCdmaInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemModemCdmaInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemModemCdmaInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopModemManager1ModemModemCdmaInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopModemManager1ModemModemCdmaInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActivationStateChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 1: { QDBusPendingReply<> _r = _t->Activate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->ActivateManual((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopModemManager1ModemModemCdmaInterface::*)(uint , uint , const QVariantMap & )>(_a, &OrgFreedesktopModemManager1ModemModemCdmaInterface::ActivationStateChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->activationState(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->cdma1xRegistrationState(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->esn(); break;
        case 3: *reinterpret_cast<uint*>(_v) = _t->evdoRegistrationState(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->meid(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->nid(); break;
        case 6: *reinterpret_cast<uint*>(_v) = _t->sid(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopModemManager1ModemModemCdmaInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopModemManager1ModemModemCdmaInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemModemCdmaInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopModemManager1ModemModemCdmaInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopModemManager1ModemModemCdmaInterface::ActivationStateChanged(uint _t1, uint _t2, const QVariantMap & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
