/*
    SPDX-FileCopyrightText: 2011-2013 Lamarque Souza <lamarque@kde.org>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef MODEMMANAGERQT_MMDEBUG_H
#define MODEMMANAGERQT_MMDEBUG_H

#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(MMQT)

#endif
