/****************************************************************************
** Meta object code from reading C++ file 'messaginginterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../modemmanager-qt-6.26.0/src/dbus/messaginginterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'messaginginterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemMessagingInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopModemManager1ModemMessagingInterface::qt_create_metaobjectdata<qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemMessagingInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopModemManager1ModemMessagingInterface",
        "Added",
        "",
        "QDBusObjectPath",
        "path",
        "received",
        "Deleted",
        "Create",
        "QDBusPendingReply<QDBusObjectPath>",
        "QVariantMap",
        "properties",
        "Delete",
        "QDBusPendingReply<>",
        "List",
        "QDBusPendingReply<QList<QDBusObjectPath>>",
        "SetDefaultStorage",
        "storage",
        "DefaultStorage",
        "Messages",
        "QList<QDBusObjectPath>",
        "SupportedStorages",
        "ModemManager::UIntList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Added'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'Deleted'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'Create'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QVariantMap &)>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(11, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'List'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath>>()>(13, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'SetDefaultStorage'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(15, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::UInt, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'DefaultStorage'
        QtMocHelpers::PropertyData<uint>(17, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'Messages'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'SupportedStorages'
        QtMocHelpers::PropertyData<ModemManager::UIntList>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopModemManager1ModemMessagingInterface, qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemMessagingInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopModemManager1ModemMessagingInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemMessagingInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemMessagingInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemMessagingInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopModemManager1ModemMessagingInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopModemManager1ModemMessagingInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Added((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->Deleted((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 2: { QDBusPendingReply<QDBusObjectPath> _r = _t->Create((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<> _r = _t->Delete((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->List();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->SetDefaultStorage((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopModemManager1ModemMessagingInterface::*)(const QDBusObjectPath & , bool )>(_a, &OrgFreedesktopModemManager1ModemMessagingInterface::Added, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopModemManager1ModemMessagingInterface::*)(const QDBusObjectPath & )>(_a, &OrgFreedesktopModemManager1ModemMessagingInterface::Deleted, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ModemManager::UIntList >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->defaultStorage(); break;
        case 1: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->messages(); break;
        case 2: *reinterpret_cast<ModemManager::UIntList*>(_v) = _t->supportedStorages(); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopModemManager1ModemMessagingInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopModemManager1ModemMessagingInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN50OrgFreedesktopModemManager1ModemMessagingInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopModemManager1ModemMessagingInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopModemManager1ModemMessagingInterface::Added(const QDBusObjectPath & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void OrgFreedesktopModemManager1ModemMessagingInterface::Deleted(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
